<table>
    <tbody>
        <tr hx-swap-oob="innerHTML:#tr-{{ object.pk }}">
            {% include 'ui/table.html#td' with object=object fields=fields queryset=queryset %}
        </tr>
    </tbody>
    {% if footer %}
        <tfoot>
            <tr hx-swap-oob="innerHTML:#tf-row">
                {% include 'ui/table.html#tf' with object=object fields=fields queryset=queryset %}
            </tr>
        </tfoot>
    {% endif %}
</table>
