{% extends 'ui/modal.html' %}
{% load i18n %}

{% block modal_content %}
    <form id="{{ modal_id }}-form" hx-post="{% url 'user:change_email' %}">
        {% csrf_token %}
        <label class="label has-field is-required">
            {{ form.email.label }}
            {{ form.email }}
            <span class="has-text-danger is-size-7">{{ form.email.errors }}</span>
        </label>
        <label class="label has-field is-required">
            {{ form.password.label }}
            {{ form.password }}
            <span class="has-text-danger is-size-7">{{ form.password.errors }}</span>
        </label>
    </form>
{% endblock %}

{% block modal_buttons %}
	<button type="submit" form="{{ modal_id }}-form" class="button is-success">{% translate 'Save' %}</button>
    {{ block.super }}
{% endblock %}

