# Generated by Django 5.1.4 on 2025-03-06 09:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accrete', '0004_rename_accessgroupmember_memberaccessgrouprel_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='accessgroup',
            name='apply_on',
            field=models.CharField(choices=[('tenant', 'Tenant'), ('member', 'Member')], default='tenant', help_text='', max_length=10, verbose_name='Apply On'),
        ),
        migrations.AlterField(
            model_name='member',
            name='access_groups',
            field=models.ManyToManyField(blank=True, through='accrete.MemberAccessGroupRel', to='accrete.accessgroup'),
        ),
        migrations.AlterField(
            model_name='tenant',
            name='access_groups',
            field=models.ManyToManyField(blank=True, through='accrete.TenantAccessGroupRel', to='accrete.accessgroup'),
        ),
    ]
