# Generated by Django 5.1.1 on 2025-01-10 08:02

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accrete', '0003_remove_member_name'),
        ('log', '0002_log_user_alter_log_new_value_type_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='log',
            name='tenant',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='accrete.tenant', verbose_name='Tenant'),
        ),
    ]
