@import url(../bulma/css/bulma.css);
:root {
  --bulma-body-size: .9em;
  --bulma-navbar-height: 40px;
  --bulma-menu-item-selected-h: --bulma-success-h;
  --accrete-content-right-width: 500px;
  --accrete-action-panel-width: 320px;
  --bulma-input-icon-focus-color: var(--bulma-success);
  --bulma-input-arrow: var(--bulma-success);
  --bulma-arrow-color: var(--bulma-success);
  --bulma-navbar-burger-color: var(--bulma-success);
  --accrete-hover-color: #F0F2F4; }

html[data-theme='light'] {
  --bulma-menu-item-h: var(--bulma-success-h);
  --bulma-menu-item-s: var(--bulma-success-s);
  --bulma-menu-item-l: var(--bulma-success-l);
  --bulma-menu-item-background-l: 50%;
  --bulma-menu-item-color-l: 10%;
  --bulma-navbar-burger-color: var(--bulma-success);
  --accrete-hover-color: #F0F2F4; }

html[data-theme='dark'] {
  --bulma-navbar-burger-color: var(--bulma-success);
  --accrete-hover-color: #1E2128; }
  html[data-theme='dark'] .button.is-light {
    --bulma-button-h: var(--bulma-dark-h);
    --bulma-button-s: var(--bulma-dark-s);
    --bulma-button-l: var(--bulma-dark-l);
    --bulma-button-background-l: var(--bulma-dark-l);
    --bulma-button-border-l: var(--bulma-dark-l);
    --bulma-button-border-width: 0px;
    --bulma-button-color-l: var(--bulma-dark-invert-l);
    --bulma-button-outer-shadow-a: 0; }
  html[data-theme='dark'] .button.is-danger.is-light {
    --bulma-button-background-l: var(--bulma-dark-l);
    --bulma-button-color-l: var(--bulma-danger-dark-invert-l); }
  html[data-theme='dark'] .tag > .button.is-light {
    --bulma-button-background-l: var(--bulma-background-l); }

[x-cloak] {
  display: none !important; }

a {
  color: inherit;
  text-decoration: inherit; }

.navbar-burger {
  color: black; }

.button.is-subtle {
  box-shadow: none;
  border: none; }

.input {
  border-top: none;
  border-right: none;
  border-left: none;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
  box-shadow: none; }

.input:focus, .input:focus-within {
  box-shadow: none;
  border-bottom: 1px solid var(--bulma-success); }

textarea {
  border-top: transparent !important;
  border-right: transparent !important;
  border-left: transparent !important;
  border-radius: 0 !important;
  box-shadow: none !important; }

textarea:focus {
  border-color: var(--bulma-success) !important; }

.is-small.textarea, .is-small.input {
  border-radius: 0;
  font-size: var(--bulma-size-small); }

td > .input, td * .input, td * select, td * .select {
  border-top: none !important;
  border-right: none !important;
  border-bottom: none !important;
  border-left: none !important; }

td:has(.input:focus) {
  border-bottom: 1px solid var(--bulma-success) !important; }

select {
  border-top: transparent !important;
  border-right: transparent !important;
  border-left: transparent !important;
  border-radius: 0 !important;
  box-shadow: none !important; }

select:focus {
  box-shadow: none;
  border-bottom: 1px solid var(--bulma-success) !important; }

#content-right-container {
  flex-shrink: 0;
  width: var(--accrete-content-right-width);
  border-top-left-radius: var(--bulma-radius-medium);
  border-bottom-left-radius: var(--bulma-radius-medium);
  box-shadow: -2px 0 20px 0 var(--bulma-grey-light);
  z-index: 20; }

.responsive-heading {
  display: none; }

#content-left-container {
  container-name: content-left-container;
  container-type: inline-size; }

.htmx-indicator {
  transition: opacity 200ms ease-in; }

.modal-request-overlay {
  pointer-events: none; }

.modal-request-overlay.htmx-request {
  pointer-events: auto; }

.list-entry > .box:hover, .box.selected {
  outline: 2px solid var(--bulma-success); }

@container content-left-container (max-width: 768px) {
  table.can-compact * td {
    width: 100%;
    float: left;
    text-align: left !important;
    border: transparent !important;
    font-size: 1em;
    padding-left: 1rem !important; }

  table.can-compact * tr {
    display: inline-block;
    width: 100%;
    padding-top: 8px;
    padding-bottom: 12px;
    border-bottom: 1px solid var(--bulma-grey-light); }

  table.can-compact * tr:first-child {
    border-top: 1px solid var(--bulma-grey-light); }

  table.can-compact * tr.is-success {
    background-color: var(--bulma-success); }

  table.can-compact * tr.is-success:hover {
    background-color: var(--bulma-success) !important; }

  table.can-compact > thead {
    display: none; }

  .responsive-heading {
    display: inline-block; }

  .list-entry {
    height: fit-content !important; } }
@media screen and (max-width: 768px) {
  #content-right-container {
    flex-grow: 1;
    flex-shrink: 1;
    width: auto;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0; }

  .level > .level-item.box {
    width: 100%; } }
#action-panel {
  max-width: var(--accrete-action-panel-width);
  min-width: var(--accrete-action-panel-width);
  height: 100%;
  overflow-y: auto; }

@media screen and (max-width: 1215px) {
  #action-panel {
    position: absolute;
    background: var(--bulma-scheme-main);
    z-index: 999;
    box-shadow: 2px 0 20px 0 var(--bulma-grey-light); } }
.menu-list a.is-active, .menu-list a.is-selected, .menu-list button.is-active, .menu-list button.is-selected, .menu-list .menu-item.is-active, .menu-list .menu-item.is-selected {
  --bulma-menu-item-h: var(--bulma-success-h);
  --bulma-menu-item-s: var(--bulma-success-s);
  --bulma-menu-item-l: var(--bulma-success-l);
  --bulma-menu-item-background-l: var(--bulma-success-l);
  --bulma-menu-item-color-l: var(--bulma-success-invert-l); }

.hoverable *:hover {
  background-color: var(--accrete-hover-color); }

/* Chrome, Safari, Edge, Opera */
input::-webkit-outer-spin-button,
input::-webkit-inner-spin-button {
  -webkit-appearance: none;
  margin: 0; }

/* Firefox */
input[type=number] {
  -moz-appearance: textfield; }

.query-group-container .query-tag-container:first-child .query-operator {
  display: none; }

.query-group-container .query-tag-container:first-child .query-operator-group {
  display: none !important; }

#query-tags > .query-group-container > .query-operator:first-child {
  display: none; }

#query-tags > .query-group-container > .query-operator-group:first-child {
  display: none !important; }

.query-group {
  padding-left: 4px;
  border-left: 1px solid var(--bulma-grey-light);
  border-top: none;
  border-right: none;
  border-bottom: none;
  border-radius: 0;
  margin-bottom: 5px; }

#query-tags > .query-group-container > .query-group {
  padding-left: 0;
  border-left: none !important; }

/*# sourceMappingURL=accrete.css.map */
